export type Escrow = {
    "version": "0.1.0";
    "name": "escrow";
    "instructions": [
        {
            "name": "setTradeConfigAuthority";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "deployerAuthority";
                    "isMut": false;
                    "isSigner": true;
                }
            ];
            "args": [
                {
                    "name": "newTradeConfigAuthority";
                    "type": "publicKey";
                }
            ];
        },
        {
            "name": "setAmlPolicyAuthority";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "deployerAuthority";
                    "isMut": true;
                    "isSigner": true;
                }
            ];
            "args": [
                {
                    "name": "newAmlPolicyAuthority";
                    "type": "publicKey";
                }
            ];
        },
        {
            "name": "addArbitratorCert";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "arbitratorAuthority";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "arbitratorCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "arbitratorCertBump";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "addToken";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "tokenInfoBump";
                    "type": "u8";
                },
                {
                    "name": "quota30Days";
                    "type": {
                        "vec": "u128";
                    };
                },
                {
                    "name": "quota24Hours";
                    "type": {
                        "vec": "u128";
                    };
                }
            ];
        },
        {
            "name": "addTokenV1";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "tokenInfoBump";
                    "type": "u8";
                },
                {
                    "name": "renecOraclePubkey";
                    "type": "publicKey";
                },
                {
                    "name": "quota30Days";
                    "type": {
                        "vec": "u128";
                    };
                },
                {
                    "name": "quota24Hours";
                    "type": {
                        "vec": "u128";
                    };
                }
            ];
        },
        {
            "name": "removeToken";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        },
        {
            "name": "setRenecRate";
            "accounts": [
                {
                    "name": "tradeConfigAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "renecRate";
                    "type": "u64";
                }
            ];
        },
        {
            "name": "setUsdRate";
            "accounts": [
                {
                    "name": "tradeConfigAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "usdRate";
                    "type": "u64";
                }
            ];
        },
        {
            "name": "setMinimumOfferAmount";
            "accounts": [
                {
                    "name": "tradeConfigAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "minimumOfferAmount";
                    "type": "u64";
                }
            ];
        },
        {
            "name": "updateConfig";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": false;
                    "isSigner": true;
                }
            ];
            "args": [
                {
                    "name": "treasuryPubkey";
                    "type": {
                        "option": "publicKey";
                    };
                },
                {
                    "name": "bondSize";
                    "type": {
                        "option": "u64";
                    };
                },
                {
                    "name": "arbitratorCommission";
                    "type": {
                        "option": "u64";
                    };
                },
                {
                    "name": "treasuryShare";
                    "type": {
                        "option": "u64";
                    };
                },
                {
                    "name": "paymentDuration";
                    "type": {
                        "option": "u64";
                    };
                },
                {
                    "name": "cancelPenaltyRate";
                    "type": {
                        "option": "u64";
                    };
                },
                {
                    "name": "limitActiveBondlessTrade";
                    "type": {
                        "option": "u16";
                    };
                }
            ];
        },
        {
            "name": "initKycCert";
            "docs": [
                "Init default kyc cert account for user. Anyone can call this ix",
                "By default, the kyc cert of the targer user is 0"
            ];
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "caller";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "user";
                    "type": "publicKey";
                },
                {
                    "name": "kycCertBump";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "setKycCert";
            "docs": [
                "only aml_policy authority can call and set the level a kyc cert of an user",
                "prerequisite: the kyc cert account of the user has been initialized by the init_kyc_cert ix"
            ];
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "amlPolicyAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "user";
                    "type": "publicKey";
                },
                {
                    "name": "level";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "removeArbitratorCert";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "arbitratorAuthority";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "arbitratorCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        },
        {
            "name": "withdrawConfigRentVaultFund";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeConfigAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "amount";
                    "type": "u64";
                }
            ];
        },
        {
            "name": "initializeConfig";
            "accounts": [
                {
                    "name": "config";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "deployer";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "configId";
                    "type": "string";
                },
                {
                    "name": "tradeConfigAuthority";
                    "type": "publicKey";
                },
                {
                    "name": "amlPolicyAuthority";
                    "type": "publicKey";
                },
                {
                    "name": "treasuryPubkey";
                    "type": "publicKey";
                },
                {
                    "name": "bondSize";
                    "type": "u64";
                },
                {
                    "name": "arbitratorCommission";
                    "type": "u64";
                },
                {
                    "name": "treasuryShare";
                    "type": "u64";
                },
                {
                    "name": "paymentDuration";
                    "type": "u64";
                },
                {
                    "name": "cancelPenaltyRate";
                    "type": "u64";
                },
                {
                    "name": "startTradeId";
                    "type": "u64";
                },
                {
                    "name": "configVaultBump";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "makeOffer";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "userTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "nativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "side";
                    "type": {
                        "defined": "TradeSide";
                    };
                },
                {
                    "name": "bondType";
                    "type": {
                        "defined": "BondType";
                    };
                },
                {
                    "name": "minTradeSize";
                    "type": "u64";
                },
                {
                    "name": "tokenAmount";
                    "type": "u64";
                },
                {
                    "name": "fiatAmount";
                    "type": "u64";
                },
                {
                    "name": "offerBump";
                    "type": "u8";
                },
                {
                    "name": "tokenVaultBump";
                    "type": "u8";
                },
                {
                    "name": "nativeVaultBump";
                    "type": "u8";
                },
                {
                    "name": "bankName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountNumber";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "nonce";
                    "type": {
                        "option": "string";
                    };
                }
            ];
        },
        {
            "name": "makeOfferV1";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "userTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "nativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "oracleProduct";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "oraclePrice";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "side";
                    "type": {
                        "defined": "TradeSide";
                    };
                },
                {
                    "name": "bondType";
                    "type": {
                        "defined": "BondType";
                    };
                },
                {
                    "name": "minTradeSize";
                    "type": "u64";
                },
                {
                    "name": "tokenAmount";
                    "type": "u64";
                },
                {
                    "name": "fiatAmount";
                    "type": "u64";
                },
                {
                    "name": "offerBump";
                    "type": "u8";
                },
                {
                    "name": "tokenVaultBump";
                    "type": "u8";
                },
                {
                    "name": "nativeVaultBump";
                    "type": "u8";
                },
                {
                    "name": "bankName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountNumber";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "nonce";
                    "type": {
                        "option": "string";
                    };
                }
            ];
        },
        {
            "name": "requestCreateTrade";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "taker";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "takerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offerTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offerNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "tokenAmount";
                    "type": "u64";
                },
                {
                    "name": "tradeBump";
                    "type": "u8";
                },
                {
                    "name": "nativeVaultBump";
                    "type": "u8";
                },
                {
                    "name": "tokenVaultBump";
                    "type": "u8";
                },
                {
                    "name": "useBondless";
                    "type": "bool";
                }
            ];
        },
        {
            "name": "cancelOffer";
            "accounts": [
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "userTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "nativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        },
        {
            "name": "cancelTrade";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "treasuryAuthority";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "treasuryTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "taker";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "takerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offerTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offerNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tradeNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        },
        {
            "name": "release";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "seller";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "buyer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "sellerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "buyerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "nativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        },
        {
            "name": "callArbitrator";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "caller";
                    "isMut": false;
                    "isSigner": true;
                }
            ];
            "args": [];
        },
        {
            "name": "resolveDispute";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "arbitratorAuthority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "treasuryAuthority";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "treasuryTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "arbitratorCert";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "arbitratorTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "seller";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "sellerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "buyer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "buyerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "nativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "disputeAction";
                    "type": {
                        "defined": "DisputeAction";
                    };
                },
                {
                    "name": "compensationAction";
                    "type": {
                        "defined": "CompensationAction";
                    };
                }
            ];
        },
        {
            "name": "savePaymentEvidence";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "evidenceAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "sellerData";
                    "type": "string";
                },
                {
                    "name": "arbitratorData";
                    "type": "string";
                },
                {
                    "name": "nonce";
                    "type": "string";
                },
                {
                    "name": "bump";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "matchingEngine";
            "accounts": [
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "kycCert";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenInfo";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "takerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "numOffers";
                    "type": "u8";
                },
                {
                    "name": "totalTradeAmount";
                    "type": "u64";
                },
                {
                    "name": "tradeAmounts";
                    "type": {
                        "vec": "u64";
                    };
                },
                {
                    "name": "tradeIds";
                    "type": {
                        "vec": "u64";
                    };
                },
                {
                    "name": "bumps";
                    "type": "bytes";
                }
            ];
        },
        {
            "name": "initMarket";
            "accounts": [
                {
                    "name": "market";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "escrowConfig";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "authority";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "bondSize";
                    "type": "u64";
                },
                {
                    "name": "renecRate";
                    "type": "u64";
                },
                {
                    "name": "marketBump";
                    "type": "u8";
                },
                {
                    "name": "tokenVaultBump";
                    "type": "u8";
                },
                {
                    "name": "nativeVaultBump";
                    "type": "u8";
                }
            ];
        },
        {
            "name": "pocMakeOffer";
            "accounts": [
                {
                    "name": "market";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "userTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "side";
                    "type": {
                        "defined": "TradeSide";
                    };
                },
                {
                    "name": "bondType";
                    "type": {
                        "defined": "BondType";
                    };
                },
                {
                    "name": "minTradeSize";
                    "type": "u64";
                },
                {
                    "name": "tokenAmount";
                    "type": "u64";
                },
                {
                    "name": "fiatAmount";
                    "type": "u64";
                },
                {
                    "name": "offerBump";
                    "type": "u8";
                },
                {
                    "name": "bankName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountNumber";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "accountName";
                    "type": {
                        "option": "string";
                    };
                },
                {
                    "name": "nonce";
                    "type": {
                        "option": "string";
                    };
                }
            ];
        },
        {
            "name": "pocMatching";
            "accounts": [
                {
                    "name": "market";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "user";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "configRentVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "takerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "numOffers";
                    "type": "u8";
                },
                {
                    "name": "totalTradeAmount";
                    "type": "u64";
                },
                {
                    "name": "tradeIds";
                    "type": {
                        "vec": "u64";
                    };
                },
                {
                    "name": "bumps";
                    "type": "bytes";
                }
            ];
        },
        {
            "name": "pocRelease";
            "accounts": [
                {
                    "name": "market";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketTokenVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "marketNativeVault";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "offer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "trade";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "seller";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "buyer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "sellerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "buyerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [];
        }
    ];
    "accounts": [
        {
            "name": "arbitratorCert";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "bump";
                        "type": "u8";
                    }
                ];
            };
        },
        {
            "name": "escrowConfig";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "configId";
                        "type": "string";
                    },
                    {
                        "name": "deployerAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "tradeConfigAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "amlPolicyAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "treasuryPubkey";
                        "type": "publicKey";
                    },
                    {
                        "name": "currentTradeId";
                        "type": "u64";
                    },
                    {
                        "name": "currentOfferId";
                        "type": "u64";
                    },
                    {
                        "name": "bondSize";
                        "type": "u64";
                    },
                    {
                        "name": "arbitratorCommission";
                        "type": "u64";
                    },
                    {
                        "name": "treasuryShare";
                        "type": "u64";
                    },
                    {
                        "name": "paymentDuration";
                        "type": "u64";
                    },
                    {
                        "name": "cancelPenaltyRate";
                        "type": "u64";
                    },
                    {
                        "name": "lastApplicableTime";
                        "type": "u64";
                    },
                    {
                        "name": "configVaultBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "limitActiveBondlessTrade";
                        "type": "u16";
                    },
                    {
                        "name": "totalActiveBondlessTrade";
                        "type": "u16";
                    }
                ];
            };
        },
        {
            "name": "evidenceAccount";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "sellerData";
                        "type": "string";
                    },
                    {
                        "name": "arbitratorData";
                        "type": "string";
                    },
                    {
                        "name": "nonce";
                        "type": "string";
                    },
                    {
                        "name": "trade";
                        "type": "publicKey";
                    }
                ];
            };
        },
        {
            "name": "kycCert";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "level";
                        "type": "u8";
                    },
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "totalTradedAmount";
                        "type": "u128";
                    },
                    {
                        "name": "totalActiveBondlessTrade";
                        "type": "u8";
                    },
                    {
                        "name": "dayVolumesHistory";
                        "type": {
                            "defined": "VolumeHistory30Days";
                        };
                    },
                    {
                        "name": "hourVolumesHistory";
                        "type": {
                            "defined": "VolumeHistory24Hours";
                        };
                    }
                ];
            };
        },
        {
            "name": "marketState";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "escrowConfig";
                        "type": "publicKey";
                    },
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "marketTokenVaultAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "marketNativeVaultAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "tokenMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "totalDepositAmount";
                        "type": "u64";
                    },
                    {
                        "name": "totalPendingAmount";
                        "type": "u64";
                    },
                    {
                        "name": "totalAvailableAmount";
                        "type": "u64";
                    },
                    {
                        "name": "currentTradeId";
                        "type": "u64";
                    },
                    {
                        "name": "currentOfferId";
                        "type": "u64";
                    },
                    {
                        "name": "bondSize";
                        "type": "u64";
                    },
                    {
                        "name": "renecRate";
                        "type": "u64";
                    },
                    {
                        "name": "marketBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "marketNativeVaultBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "marketTokenVaultBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "offer";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "offerId";
                        "type": "u64";
                    },
                    {
                        "name": "offerIdSeed";
                        "type": {
                            "array": [
                                "u8",
                                8
                            ];
                        };
                    },
                    {
                        "name": "side";
                        "type": {
                            "defined": "TradeSide";
                        };
                    },
                    {
                        "name": "state";
                        "type": {
                            "defined": "OfferState";
                        };
                    },
                    {
                        "name": "bondType";
                        "type": {
                            "defined": "BondType";
                        };
                    },
                    {
                        "name": "escrowConfig";
                        "type": "publicKey";
                    },
                    {
                        "name": "configRentVault";
                        "type": "publicKey";
                    },
                    {
                        "name": "makerAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "makerTokenAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "tokenVaultAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "nativeVaultAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "tokenMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "bondAmount";
                        "type": "u64";
                    },
                    {
                        "name": "fiatAmount";
                        "type": "u64";
                    },
                    {
                        "name": "totalAmount";
                        "type": "u64";
                    },
                    {
                        "name": "pendingAmount";
                        "type": "u64";
                    },
                    {
                        "name": "availableAmount";
                        "type": "u64";
                    },
                    {
                        "name": "filledAmount";
                        "type": "u64";
                    },
                    {
                        "name": "minTradeSize";
                        "type": "u64";
                    },
                    {
                        "name": "createdAt";
                        "type": "u64";
                    },
                    {
                        "name": "finishedAt";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "nativeVaultBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "bankName";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "accountNumber";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "accountName";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "nonce";
                        "type": {
                            "option": "string";
                        };
                    }
                ];
            };
        },
        {
            "name": "product";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "version";
                        "type": "u16";
                    },
                    {
                        "name": "status";
                        "type": {
                            "defined": "ProductStatus";
                        };
                    },
                    {
                        "name": "assetType";
                        "type": {
                            "defined": "AssetType";
                        };
                    },
                    {
                        "name": "quoteCurrency";
                        "type": "string";
                    },
                    {
                        "name": "quoteMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "baseCurrency";
                        "type": "string";
                    },
                    {
                        "name": "baseMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "priceAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "expo";
                        "type": "i32";
                    },
                    {
                        "name": "maxPrice";
                        "type": "u64";
                    },
                    {
                        "name": "minPrice";
                        "type": "u64";
                    },
                    {
                        "name": "windowSize";
                        "type": "u64";
                    },
                    {
                        "name": "controller";
                        "type": "publicKey";
                    },
                    {
                        "name": "bump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "price";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "version";
                        "type": "u16";
                    },
                    {
                        "name": "status";
                        "type": {
                            "defined": "PriceStatus";
                        };
                    },
                    {
                        "name": "productAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "price";
                        "type": "u64";
                    },
                    {
                        "name": "numPublishers";
                        "type": "u16";
                    },
                    {
                        "name": "timestamp";
                        "type": "u64";
                    },
                    {
                        "name": "prevPrice";
                        "type": "u64";
                    },
                    {
                        "name": "prevTimestamp";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "tokenInfo";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "tokenDecimal";
                        "type": "u8";
                    },
                    {
                        "name": "renecRate";
                        "type": "u64";
                    },
                    {
                        "name": "usdRate";
                        "type": "u64";
                    },
                    {
                        "name": "minimumOfferAmount";
                        "type": "u64";
                    },
                    {
                        "name": "quota24Hours";
                        "type": {
                            "vec": "u128";
                        };
                    },
                    {
                        "name": "quota30Days";
                        "type": {
                            "vec": "u128";
                        };
                    },
                    {
                        "name": "expo";
                        "type": "u8";
                    }
                ];
            };
        },
        {
            "name": "tokenInfoV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "tokenDecimal";
                        "type": "u8";
                    },
                    {
                        "name": "renecOraclePubkey";
                        "type": "publicKey";
                    },
                    {
                        "name": "minimumOfferAmount";
                        "type": "u64";
                    },
                    {
                        "name": "quota24Hours";
                        "type": {
                            "vec": "u128";
                        };
                    },
                    {
                        "name": "quota30Days";
                        "type": {
                            "vec": "u128";
                        };
                    }
                ];
            };
        },
        {
            "name": "trade";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "offerId";
                        "type": "u64";
                    },
                    {
                        "name": "tradeId";
                        "type": "u64";
                    },
                    {
                        "name": "tradeIdSeed";
                        "type": {
                            "array": [
                                "u8",
                                8
                            ];
                        };
                    },
                    {
                        "name": "side";
                        "type": {
                            "defined": "TradeSide";
                        };
                    },
                    {
                        "name": "state";
                        "type": {
                            "defined": "TradeState";
                        };
                    },
                    {
                        "name": "bondType";
                        "type": {
                            "defined": "BondType";
                        };
                    },
                    {
                        "name": "escrowConfig";
                        "type": "publicKey";
                    },
                    {
                        "name": "configRentVault";
                        "type": "publicKey";
                    },
                    {
                        "name": "sellerAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "sellerTokenAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "buyerAuthority";
                        "type": "publicKey";
                    },
                    {
                        "name": "buyerTokenAccount";
                        "type": "publicKey";
                    },
                    {
                        "name": "tokenMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "tokenVault";
                        "type": "publicKey";
                    },
                    {
                        "name": "nativeVault";
                        "type": "publicKey";
                    },
                    {
                        "name": "bondAmount";
                        "type": "u64";
                    },
                    {
                        "name": "tokenAmount";
                        "type": "u64";
                    },
                    {
                        "name": "fiatAmount";
                        "type": "u64";
                    },
                    {
                        "name": "createdAt";
                        "type": "u64";
                    },
                    {
                        "name": "finishedAt";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "nativeVaultBump";
                        "type": {
                            "array": [
                                "u8",
                                1
                            ];
                        };
                    },
                    {
                        "name": "bankName";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "accountNumber";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "accountName";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "nonce";
                        "type": {
                            "option": "string";
                        };
                    },
                    {
                        "name": "useBondless";
                        "type": "bool";
                    }
                ];
            };
        }
    ];
    "types": [
        {
            "name": "VolumeHistory30Days";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "head";
                        "type": "u8";
                    },
                    {
                        "name": "volumes";
                        "type": {
                            "array": [
                                "u64",
                                30
                            ];
                        };
                    },
                    {
                        "name": "lastApplicableTime";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "VolumeHistory24Hours";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "head";
                        "type": "u8";
                    },
                    {
                        "name": "volumes";
                        "type": {
                            "array": [
                                "u64",
                                24
                            ];
                        };
                    },
                    {
                        "name": "lastApplicableTime";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "ErrorCode";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "InvalidInput";
                    },
                    {
                        "name": "NumberCastError";
                    },
                    {
                        "name": "InvalidTimestampConversion";
                    },
                    {
                        "name": "InvalidTokenAccountMint";
                    },
                    {
                        "name": "InvalidState";
                    },
                    {
                        "name": "InvalidCaller";
                    },
                    {
                        "name": "StillPaymentTime";
                    },
                    {
                        "name": "UnauthorizedCanceller";
                    },
                    {
                        "name": "SelfJoin";
                    },
                    {
                        "name": "InvalidKycLevel";
                    },
                    {
                        "name": "QuotaExceeded";
                    },
                    {
                        "name": "UserParticipated";
                    },
                    {
                        "name": "AmountCalcOverflow";
                    },
                    {
                        "name": "DivisionByZero";
                    },
                    {
                        "name": "Unimplemented";
                    },
                    {
                        "name": "RenecRateNotSet";
                    },
                    {
                        "name": "MinTradeSizeNotValid";
                    },
                    {
                        "name": "BelowMinimumOfferamount";
                    },
                    {
                        "name": "BelowMinimumTradeAmount";
                    },
                    {
                        "name": "NotEnoughBalance";
                    },
                    {
                        "name": "InvalidBondType";
                    },
                    {
                        "name": "OfferCanceled";
                    },
                    {
                        "name": "DayQuotaExceeded";
                    },
                    {
                        "name": "MonthQuotaExceeded";
                    },
                    {
                        "name": "PendingAmountNotZero";
                    },
                    {
                        "name": "InvalidPriceOfProductOracle";
                    },
                    {
                        "name": "UnavailableProduct";
                    },
                    {
                        "name": "UnavailablePrice";
                    },
                    {
                        "name": "PriceTooOld";
                    },
                    {
                        "name": "ExpoPositiveNonSupport";
                    },
                    {
                        "name": "PriceMustBeNonZero";
                    },
                    {
                        "name": "InvalidProduct";
                    },
                    {
                        "name": "MaxBondlessTrade";
                    },
                    {
                        "name": "TradeVolumeNotAllowBondLess";
                    },
                    {
                        "name": "LimitBondlessTrade";
                    },
                    {
                        "name": "AmountCalcUnderflow";
                    },
                    {
                        "name": "OverLimitOfferPerMatching";
                    },
                    {
                        "name": "InvalidTradeAmount";
                    }
                ];
            };
        },
        {
            "name": "AssetType";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Forex";
                    },
                    {
                        "name": "Crypto";
                    }
                ];
            };
        },
        {
            "name": "ProductStatus";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Unknown";
                    },
                    {
                        "name": "Offline";
                    },
                    {
                        "name": "Online";
                    }
                ];
            };
        },
        {
            "name": "PriceStatus";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Unknown";
                    },
                    {
                        "name": "Offline";
                    },
                    {
                        "name": "Online";
                    }
                ];
            };
        },
        {
            "name": "TokenInfoVersion";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "V0";
                        "fields": [
                            {
                                "defined": "&'aTokenInfo";
                            }
                        ];
                    },
                    {
                        "name": "V1";
                        "fields": [
                            {
                                "defined": "&'aTokenInfoV1";
                            }
                        ];
                    }
                ];
            };
        },
        {
            "name": "TradeState";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Awaiting";
                    },
                    {
                        "name": "Deposited";
                    },
                    {
                        "name": "Disputed";
                    },
                    {
                        "name": "Released";
                    },
                    {
                        "name": "Canceled";
                    }
                ];
            };
        },
        {
            "name": "OfferState";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Awaiting";
                    },
                    {
                        "name": "Canceled";
                    },
                    {
                        "name": "OutOfFund";
                    }
                ];
            };
        },
        {
            "name": "TradeSide";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Buy";
                    },
                    {
                        "name": "Sell";
                    }
                ];
            };
        },
        {
            "name": "BondType";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Native";
                    },
                    {
                        "name": "Spl";
                    }
                ];
            };
        },
        {
            "name": "DisputeAction";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Release";
                    },
                    {
                        "name": "Cancel";
                    }
                ];
            };
        },
        {
            "name": "CompensationAction";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "NoCompensate";
                    },
                    {
                        "name": "CompensateSeller";
                    },
                    {
                        "name": "CompensateBuyer";
                    }
                ];
            };
        }
    ];
};
export declare const IDL: Escrow;
