/// <reference types="bn.js" />
import { PublicKey } from "@solana/web3.js";
import { TransactionBuilder } from "@orca-so/common-sdk";
import { ConfigOptionParams, EscrowConfigData, EscrowContext, EscrowFetcher, KycCertData, OfferQuotes, PDA, TokenInfoData } from "..";
import { BN } from "@project-serum/anchor";
export declare class EscrowConfigClient {
    ctx: EscrowContext;
    escrowFetcher: EscrowFetcher;
    publicKey: PublicKey;
    data: EscrowConfigData;
    pda: PDA;
    constructor(ctx: EscrowContext, publicKey: PublicKey, pda: PDA, data: EscrowConfigData);
    static getConfig(ctx: EscrowContext, configId: string | PublicKey): Promise<EscrowConfigClient>;
    setTradeConfigAuthority(deployerPubkey: PublicKey, newTradeConfigAuthority: PublicKey): Promise<TransactionBuilder>;
    setAmlPolicyAuthority(deployerPubkey: PublicKey, newAmlPolicyAuthority: PublicKey): Promise<TransactionBuilder>;
    addArbitratorCert(tradeConfigAuthority: PublicKey, arbitratorAuthority: PublicKey): Promise<TransactionBuilder>;
    addToken(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, quota30Days: BN[], quota24Hours: BN[]): Promise<TransactionBuilder>;
    addTokenV1(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, renecOraclePubkey: PublicKey, quota30Days: BN[], quota24Hours: BN[]): Promise<TransactionBuilder>;
    removeToken(tradeConfigAuthority: PublicKey, tokenMint: PublicKey): Promise<TransactionBuilder>;
    setRenecRate(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, renecRate: BN): Promise<TransactionBuilder>;
    setUsdRate(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, usdRate: BN): Promise<TransactionBuilder>;
    setMinmumOfferAmount(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, minimumOfferAmount: BN): Promise<TransactionBuilder>;
    removeArbitratorCert(tradeConfigAuthority: PublicKey, arbitratorAuthority: PublicKey): Promise<TransactionBuilder>;
    updateConfig(tradeConfigAuthority: PublicKey, option: ConfigOptionParams): Promise<TransactionBuilder>;
    setKycCert(amlPolicyAuthority: PublicKey, tokenMint: PublicKey, user: PublicKey, level: number): Promise<TransactionBuilder>;
    getKycCert(tokenMint: PublicKey, user: PublicKey): Promise<KycCertData>;
    getTokenInfo(tokenMint: PublicKey): Promise<TokenInfoData>;
    getTokenInfoV1(tokenMint: PublicKey): Promise<TokenInfoData>;
    isArbitrator(arbitratorAuthority: PublicKey): Promise<boolean>;
    refresh(): Promise<EscrowConfigClient>;
    withdrawConfigRentVaultFund(amount: BN): Promise<TransactionBuilder>;
    getOffersQuotesMatchingEngine(tradeAmount: BN, tokenMint: PublicKey): Promise<OfferQuotes | null>;
    getPocOffersQuotesMatchingEngine(tradeAmount: BN, tokenMint: PublicKey): Promise<OfferQuotes | null>;
    matchAndCreateTrade(user: PublicKey, tradeAmount: BN, offerQuotes: OfferQuotes): Promise<{
        tx: TransactionBuilder;
        ids: BN[];
    }>;
    initMarket(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, bondSize: BN, renecRate: BN): Promise<TransactionBuilder>;
    pocMatching(user: PublicKey, tradeAmount: BN, offerQuotes: OfferQuotes): Promise<{
        tx: TransactionBuilder;
        ids: BN[];
    }>;
}
