"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EscrowConfigClient = void 0;
const common_sdk_1 = require("@orca-so/common-sdk");
const __1 = require("..");
const anchor_1 = require("@project-serum/anchor");
class EscrowConfigClient {
    constructor(ctx, publicKey, pda, data) {
        this.ctx = ctx;
        this.publicKey = publicKey;
        this.data = data;
        this.pda = pda;
        this.escrowFetcher = new __1.EscrowFetcher(ctx.connection, pda);
    }
    static getConfig(ctx, configId) {
        return __awaiter(this, void 0, void 0, function* () {
            let configAddress;
            if (typeof configId == "string") {
                const pda = new __1.PDA(ctx.program.programId, configId);
                configAddress = pda.getConfigPDA().key;
            }
            else {
                configAddress = configId;
            }
            const escrowConfigData = (yield ctx.program.account.escrowConfig.fetch(configAddress));
            const pda = new __1.PDA(ctx.program.programId, escrowConfigData.configId);
            return new EscrowConfigClient(ctx, configAddress, pda, escrowConfigData);
        });
    }
    setTradeConfigAuthority(deployerPubkey, newTradeConfigAuthority) {
        return __awaiter(this, void 0, void 0, function* () {
            const tx = (yield this.ctx.ixs.setTradeConfigAuthorityIx({
                escrowConfigPubkey: this.publicKey,
                deployerPubkey: deployerPubkey,
                newTradeConfigAuthority,
            })).toTx();
            return tx;
        });
    }
    setAmlPolicyAuthority(deployerPubkey, newAmlPolicyAuthority) {
        return __awaiter(this, void 0, void 0, function* () {
            const tx = (yield this.ctx.ixs.setAmlPolicyAuthorityIx({
                escrowConfigPubkey: this.publicKey,
                deployerPubkey: deployerPubkey,
                newAmlPolicyAuthority,
            })).toTx();
            return tx;
        });
    }
    addArbitratorCert(tradeConfigAuthority, arbitratorAuthority) {
        return __awaiter(this, void 0, void 0, function* () {
            let arbitratorCertPDA = this.pda.getArbitratorCertPDA(arbitratorAuthority);
            const tx = (yield this.ctx.ixs.addArbitratorCertIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                arbitratorAuthority,
                arbitratorCert: arbitratorCertPDA.key,
                arbitratorCertBump: arbitratorCertPDA.bump,
            })).toTx();
            return tx;
        });
    }
    addToken(tradeConfigAuthority, tokenMint, quota30Days, quota24Hours) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tx = (yield this.ctx.ixs.addTokenIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
                tokenInfoBump: tokenInfoPDA.bump,
                quota30Days,
                quota24Hours,
            })).toTx();
            return tx;
        });
    }
    addTokenV1(tradeConfigAuthority, tokenMint, renecOraclePubkey, quota30Days, quota24Hours) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoV1PDA(tokenMint);
            const tx = (yield this.ctx.ixs.addTokenV1Ix({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
                tokenInfoBump: tokenInfoPDA.bump,
                quota30Days,
                quota24Hours,
                renecOraclePubkey,
            })).toTx();
            return tx;
        });
    }
    removeToken(tradeConfigAuthority, tokenMint) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tx = (yield this.ctx.ixs.removeTokenIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
            })).toTx();
            return tx;
        });
    }
    setRenecRate(tradeConfigAuthority, tokenMint, renecRate) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tx = (yield this.ctx.ixs.setRenecRateIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
                renecRate,
            })).toTx();
            return tx;
        });
    }
    setUsdRate(tradeConfigAuthority, tokenMint, usdRate) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tx = (yield this.ctx.ixs.setUsdRateIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
                usdRate,
            })).toTx();
            return tx;
        });
    }
    setMinmumOfferAmount(tradeConfigAuthority, tokenMint, minimumOfferAmount) {
        return __awaiter(this, void 0, void 0, function* () {
            let tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tx = (yield this.ctx.ixs.setMinimumOfferAmount({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                tokenMint,
                tokenInfoPubkey: tokenInfoPDA.key,
                minimumOfferAmount,
            })).toTx();
            return tx;
        });
    }
    removeArbitratorCert(tradeConfigAuthority, arbitratorAuthority) {
        return __awaiter(this, void 0, void 0, function* () {
            let arbitratorCertPDA = this.pda.getArbitratorCertPDA(arbitratorAuthority);
            const tx = (yield this.ctx.ixs.removeArbitratorCertIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                arbitratorAuthority,
                arbitratorCert: arbitratorCertPDA.key,
            })).toTx();
            return tx;
        });
    }
    updateConfig(tradeConfigAuthority, option) {
        return __awaiter(this, void 0, void 0, function* () {
            let configPDA = this.pda.getConfigPDA();
            const { arbitratorCommission = null, bondSize = null, paymentDuration = null, treasuryPubkey = null, treasuryShare = null, cancelPenaltyRate = null, limitActiveBondlessTrade = null, } = option;
            const tx = (yield this.ctx.ixs.updateConfigIx({
                escrowConfigPubkey: configPDA.key,
                tradeConfigAuthority: tradeConfigAuthority,
                treasuryPubkey,
                bondSize,
                arbitratorCommission,
                treasuryShare,
                paymentDuration,
                cancelPenaltyRate,
                limitActiveBondlessTrade,
            })).toTx();
            return tx;
        });
    }
    setKycCert(amlPolicyAuthority, tokenMint, user, level) {
        return __awaiter(this, void 0, void 0, function* () {
            const kycCertPDA = this.pda.getKycCertPDA(tokenMint, user);
            const accountInfo = yield this.ctx.connection.getAccountInfo(kycCertPDA.key);
            const tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            // If the account doesn't exist, we need to initialize it
            let prependIxs = [];
            if (accountInfo == null) {
                const initKycCertIx = (yield this.ctx.ixs.initKycCertIx({
                    escrowConfig: this.publicKey,
                    caller: amlPolicyAuthority,
                    user,
                    tokenMint,
                    kycCertPubkey: kycCertPDA.key,
                    kycCertBump: kycCertPDA.bump,
                })).ix;
                if (!initKycCertIx) {
                    throw new Error("Fail to get the initialize kyc cert instruction");
                }
                prependIxs.push(initKycCertIx);
            }
            // create the setKycCertIx transaction
            const tx = (yield this.ctx.ixs.setKycCertIx({
                escrowConfig: this.publicKey,
                amlPolicyAuthority,
                user,
                tokenMint,
                tokenInfo: tokenInfoPDA.key,
                kycCertPubkey: kycCertPDA.key,
                level,
            }))
                .toTx()
                .prependInstructions(prependIxs);
            return tx;
        });
    }
    getKycCert(tokenMint, user) {
        return __awaiter(this, void 0, void 0, function* () {
            const kycCertPDA = this.pda.getKycCertPDA(tokenMint, user);
            const kycCertData = (yield this.ctx.program.account.kycCert.fetch(kycCertPDA.key));
            return kycCertData;
        });
    }
    getTokenInfo(tokenMint) {
        return __awaiter(this, void 0, void 0, function* () {
            const tokenInfoPDA = this.pda.getTokenInfoPDA(tokenMint);
            const tokenInfoData = (yield this.ctx.program.account.tokenInfo.fetch(tokenInfoPDA.key));
            return tokenInfoData;
        });
    }
    getTokenInfoV1(tokenMint) {
        return __awaiter(this, void 0, void 0, function* () {
            const tokenInfoPDA = this.pda.getTokenInfoV1PDA(tokenMint);
            const tokenInfoData = (yield this.ctx.program.account.tokenInfoV1.fetch(tokenInfoPDA.key));
            return tokenInfoData;
        });
    }
    isArbitrator(arbitratorAuthority) {
        return __awaiter(this, void 0, void 0, function* () {
            let arbitratorCertPDA = this.pda.getArbitratorCertPDA(arbitratorAuthority);
            try {
                yield this.ctx.program.account.arbitratorCert.fetch(arbitratorCertPDA.key);
                return true;
            }
            catch (_a) {
                return false;
            }
        });
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            const escrowConfigData = (yield this.ctx.program.account.escrowConfig.fetch(this.publicKey));
            this.data = escrowConfigData;
            return this;
        });
    }
    withdrawConfigRentVaultFund(amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const { tradeConfigAuthority } = this.data;
            const configRentVaultFund = this.pda.getConfigRentVaultPDA().key;
            const tx = (yield this.ctx.ixs.withdrawConfigRentVaultFundIx({
                escrowConfigPubkey: this.publicKey,
                tradeConfigAuthority,
                configRentVaultFund,
                amount,
            })).toTx();
            return tx;
        });
    }
    getOffersQuotesMatchingEngine(tradeAmount, tokenMint) {
        return __awaiter(this, void 0, void 0, function* () {
            const offersAccountData = yield this.escrowFetcher.getOffersByStatus(__1.OfferState.Awaiting);
            const matchedOffers = (0, __1.matchingOffersV2)(offersAccountData, tradeAmount);
            if (!matchedOffers.length) {
                return null;
            }
            //
            const bumps = [];
            const tradeAmounts = [];
            const remainingAccounts = [];
            const tradeIds = [];
            let currentTradeId = (yield this.ctx.program.account.escrowConfig.fetch(this.publicKey)).currentTradeId;
            let remainAmount = tradeAmount;
            for (const offerData of matchedOffers) {
                if (offerData.availableAmount.gte(remainAmount)) {
                    tradeAmounts.push(remainAmount);
                }
                else {
                    tradeAmounts.push(offerData.availableAmount);
                    remainAmount = remainAmount.sub(offerData.availableAmount);
                }
                // get PDA Vault account
                const tradePDA = this.pda.getTradePDA(currentTradeId);
                const tradeTokenVaultPDA = this.pda.getTradeTokenVaultPDA(currentTradeId);
                const tradeNativeVaultPDA = this.pda.getTradeNativeVaultPDA(currentTradeId);
                const offerTokenVaultPDA = this.pda.getOfferTokenVaultPDA(offerData.offerId);
                const offerNativeVaultPDA = this.pda.getOfferNativeVaultPDA(offerData.offerId);
                // bump for vault
                bumps.push(tradePDA.bump);
                bumps.push(tradeTokenVaultPDA.bump);
                bumps.push(tradeNativeVaultPDA.bump);
                // filled remaining_accounts
                const accounts = [
                    offerData.pubkey,
                    offerTokenVaultPDA.key,
                    offerNativeVaultPDA.key,
                    tradePDA.key,
                    tradeTokenVaultPDA.key,
                    tradeNativeVaultPDA.key,
                ];
                const accountMeta = accounts.map((pubkey) => {
                    return {
                        isSigner: false,
                        isWritable: true,
                        pubkey: pubkey,
                    };
                });
                remainingAccounts.push(...accountMeta);
                tradeIds.push(currentTradeId);
                currentTradeId = currentTradeId.add(new anchor_1.BN(1));
            }
            return {
                tokenMint: tokenMint,
                numOffers: tradeAmounts.length,
                remainingAccounts: remainingAccounts,
                tradeIds: tradeIds,
                bumps: bumps,
                tradeAmounts: tradeAmounts,
            };
        });
    }
    getPocOffersQuotesMatchingEngine(tradeAmount, tokenMint) {
        return __awaiter(this, void 0, void 0, function* () {
            const offersAccountData = yield this.escrowFetcher.getOffersByStatus(__1.OfferState.Awaiting);
            const matchedOffers = (0, __1.pocMatchingOffers)(offersAccountData, tradeAmount);
            if (!matchedOffers.length) {
                return null;
            }
            console.log({ matchedOffers: matchedOffers.length });
            // //
            const market = this.pda.getMarketPDA(tokenMint).key;
            const bumps = [];
            const remainingAccounts = [];
            const tradeIds = [];
            let currentTradeId = (yield this.ctx.program.account.marketState.fetch(market)).currentTradeId;
            for (const offerData of matchedOffers) {
                // get PDA Vault account
                const tradePDA = this.pda.getPocTradePDA(currentTradeId, market);
                // bump for vault
                bumps.push(tradePDA.bump);
                // filled remaining_accounts
                const accounts = [offerData.pubkey, tradePDA.key];
                const accountMeta = accounts.map((pubkey) => {
                    return {
                        isSigner: false,
                        isWritable: true,
                        pubkey: pubkey,
                    };
                });
                remainingAccounts.push(...accountMeta);
                tradeIds.push(currentTradeId);
                currentTradeId = currentTradeId.add(new anchor_1.BN(1));
            }
            return {
                tokenMint: tokenMint,
                numOffers: matchedOffers.length,
                remainingAccounts: remainingAccounts,
                tradeIds: tradeIds,
                bumps: bumps
            };
        });
    }
    matchAndCreateTrade(user, tradeAmount, offerQuotes) {
        return __awaiter(this, void 0, void 0, function* () {
            // validate offer quotes valid
            (0, __1.validateOfferQuotes)(offerQuotes);
            //
            let prependIxs = [];
            // Get or create joiner token acccount
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, user, offerQuotes.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, user), { address: userTokenAccount } = _a, instruction = __rest(_a, ["address"]);
            prependIxs.push(instruction);
            const userKycCertPda = this.pda.getKycCertPDA(offerQuotes.tokenMint, user);
            const accountInfo = yield this.ctx.connection.getAccountInfo(userKycCertPda.key);
            if (accountInfo == null) {
                const initKycCertIx = (yield this.ctx.ixs.initKycCertIx({
                    escrowConfig: this.publicKey,
                    caller: user,
                    user,
                    tokenMint: offerQuotes.tokenMint,
                    kycCertPubkey: userKycCertPda.key,
                    kycCertBump: userKycCertPda.bump,
                })).ix;
                if (!initKycCertIx) {
                    throw new Error("Fail to get the initialize kyc cert instruction");
                }
                prependIxs.push(initKycCertIx);
            }
            const tx = (yield this.ctx.ixs.matchAndCreateTrade({
                escrowConfig: this.publicKey,
                configRentVault: this.pda.getConfigRentVaultPDA().key,
                tokenMint: offerQuotes.tokenMint,
                tokenInfo: this.pda.getTokenInfoPDA(offerQuotes.tokenMint).key,
                kycCert: userKycCertPda.key,
                user,
                userTokenAccount,
                totalTradeAmount: tradeAmount,
                tradeAmounts: offerQuotes.tradeAmounts,
                numOffers: offerQuotes.numOffers,
                tradeIds: offerQuotes.tradeIds,
                bumps: offerQuotes.bumps,
                remainingAccounts: offerQuotes.remainingAccounts,
            }))
                .toTx()
                .prependInstructions(prependIxs);
            return { tx: tx, ids: offerQuotes.tradeIds };
        });
    }
    initMarket(tradeConfigAuthority, tokenMint, bondSize, renecRate) {
        return __awaiter(this, void 0, void 0, function* () {
            let configPDA = this.pda.getConfigPDA();
            const marketPDA = this.pda.getMarketPDA(tokenMint);
            const marketTokenVaultPDA = this.pda.getMarketTokenVaultPDA(marketPDA.key);
            const marketNativeVaultPDA = this.pda.getMarketNativeVaultPDA(marketPDA.key);
            const tx = (yield this.ctx.ixs.initializeMarket({
                marketPDA: marketPDA,
                escrowConfig: configPDA.key,
                tokenMint: tokenMint,
                marketTokenVaultPDA: marketTokenVaultPDA,
                marketNativeVaultPDA: marketNativeVaultPDA,
                authority: tradeConfigAuthority,
                bondSize: bondSize,
                renecRate: renecRate,
            })).toTx();
            return tx;
        });
    }
    pocMatching(user, tradeAmount, offerQuotes) {
        return __awaiter(this, void 0, void 0, function* () {
            // validate offer quotes valid
            (0, __1.validateOfferQuotes)(offerQuotes);
            const marketPDA = this.pda.getMarketPDA(offerQuotes.tokenMint);
            const marketTokenVaultPDA = this.pda.getMarketTokenVaultPDA(marketPDA.key);
            const marketNativeVaultPDA = this.pda.getMarketNativeVaultPDA(marketPDA.key);
            //
            let prependIxs = [];
            // Get or create joiner token acccount
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, user, offerQuotes.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, user), { address: userTokenAccount } = _a, instruction = __rest(_a, ["address"]);
            prependIxs.push(instruction);
            const tx = (yield this.ctx.ixs.pocMatching({
                market: marketPDA.key,
                marketTokenVault: marketTokenVaultPDA.key,
                marketNativeVault: marketNativeVaultPDA.key,
                configRentVault: this.pda.getConfigRentVaultPDA().key,
                user,
                userTokenAccount,
                totalTradeAmount: tradeAmount,
                numOffers: offerQuotes.numOffers,
                tradeIds: offerQuotes.tradeIds,
                bumps: offerQuotes.bumps,
                remainingAccounts: offerQuotes.remainingAccounts,
            }))
                .toTx()
                .prependInstructions(prependIxs);
            return { tx: tx, ids: offerQuotes.tradeIds };
        });
    }
}
exports.EscrowConfigClient = EscrowConfigClient;
