"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapOfferStateToByte = exports.getOfferMakerAddressOffset = exports.getOfferStateOffset = exports.mapSideToByte = exports.mapTradeStateToByte = exports.getTradeOfferIdOffset = exports.getTradeSellerAddressOffset = exports.getTradeBuyerAddressOffset = exports.getTradeStateOffSet = void 0;
const types_1 = require("../types");
const bytes_1 = require("@project-serum/anchor/dist/cjs/utils/bytes");
const lodash_1 = require("lodash");
const getTradeStateOffSet = () => {
    return (8 + // DISCRIMINATOR
        8 + // offer id
        8 + // trade id
        8 + // trade id seed
        1 // side
    );
};
exports.getTradeStateOffSet = getTradeStateOffSet;
const getTradeBuyerAddressOffset = () => {
    return (8 + // DISCRIMINATOR
        8 + // offer id
        8 + // trade id
        8 + // trade id seed
        1 + // side
        1 + // bond type
        1 + // trade state
        32 + // escrow config
        32 + // config rent vault
        32 + // seller address
        32 // seller token acount
    );
};
exports.getTradeBuyerAddressOffset = getTradeBuyerAddressOffset;
const getTradeSellerAddressOffset = () => {
    return (8 + // DISCRIMINATOR
        8 + // offer id
        8 + // trade id
        8 + // trade id seed
        1 + // side
        1 + // bond type
        1 + // trade state
        32 + // escrow config
        32 // config rent vault
    );
};
exports.getTradeSellerAddressOffset = getTradeSellerAddressOffset;
const getTradeOfferIdOffset = () => {
    return 8; // DISCRIMINATOR
};
exports.getTradeOfferIdOffset = getTradeOfferIdOffset;
const mapTradeStateToByte = (tradeState) => {
    let tradeStateIntValue;
    if ((0, lodash_1.isEqual)(tradeState, types_1.TradeState.Awaiting)) {
        tradeStateIntValue = 0;
    }
    else if ((0, lodash_1.isEqual)(tradeState, types_1.TradeState.Deposited)) {
        tradeStateIntValue = 1;
    }
    else if ((0, lodash_1.isEqual)(tradeState, types_1.TradeState.Disputed)) {
        tradeStateIntValue = 2;
    }
    else if ((0, lodash_1.isEqual)(tradeState, types_1.TradeState.Released)) {
        tradeStateIntValue = 3;
    }
    else if ((0, lodash_1.isEqual)(tradeState, types_1.TradeState.Canceled)) {
        tradeStateIntValue = 4;
    }
    else {
        tradeStateIntValue = 0; // default value
    }
    let value = bytes_1.bs58.encode(Buffer.from([tradeStateIntValue]));
    return value;
};
exports.mapTradeStateToByte = mapTradeStateToByte;
const mapSideToByte = (tradeSide) => {
    let tradeSideIntValue;
    if ((0, lodash_1.isEqual)(tradeSide, types_1.TradeSide.Buy)) {
        tradeSideIntValue = 0;
    }
    else if ((0, lodash_1.isEqual)(tradeSide, types_1.TradeSide.Sell)) {
        tradeSideIntValue = 1;
    }
    else {
        tradeSideIntValue = 0; // default value
    }
    let value = bytes_1.bs58.encode(Buffer.from([tradeSideIntValue]));
    return value;
};
exports.mapSideToByte = mapSideToByte;
const getOfferStateOffset = () => {
    return (8 + // DISCRIMINATOR
        8 + // offer id
        8 + // offer id seed
        1 // side
    );
};
exports.getOfferStateOffset = getOfferStateOffset;
const getOfferMakerAddressOffset = () => {
    return (8 + // DISCRIMINATOR
        8 + // offer id
        8 + // offer id seed
        1 + // side
        1 + // bond type
        1 + // state
        32 + // escrow config
        32 // config rent vault
    );
};
exports.getOfferMakerAddressOffset = getOfferMakerAddressOffset;
const mapOfferStateToByte = (offerState) => {
    let offerStateIntValue;
    if ((0, lodash_1.isEqual)(offerState, types_1.OfferState.Awaiting)) {
        offerStateIntValue = 0;
    }
    else if ((0, lodash_1.isEqual)(offerState, types_1.OfferState.Canceled)) {
        offerStateIntValue = 1;
    }
    else if ((0, lodash_1.isEqual)(offerState, types_1.OfferState.OutOfFund)) {
        offerStateIntValue = 2;
    }
    else {
        offerStateIntValue = 0; // default value
    }
    let value = bytes_1.bs58.encode(Buffer.from([offerStateIntValue]));
    return value;
};
exports.mapOfferStateToByte = mapOfferStateToByte;
