/// <reference types="bn.js" />
import { BN, BorshAccountsCoder } from "@project-serum/anchor";
import { AccountMeta, PublicKey } from "@solana/web3.js";
export declare enum AccountName {
    EscrowConfig = "EscrowConfig",
    Trade = "Trade",
    KycCert = "KycCert",
    ArbitratorCert = "ArbitratorCert",
    TokenInfo = "TokenInfo",
    Offer = "Offer"
}
export declare const ESCROW_CODER: BorshAccountsCoder<string>;
export declare const sizeOf: (accountName: AccountName) => number;
export declare const ESCROW_CONFIG_SIZE: number;
export declare const TRADE_SIZE = 626;
export declare const OFFER_SIZE = 585;
export type EscrowConfigData = {
    configId: string;
    deployerAuthority: PublicKey;
    tradeConfigAuthority: PublicKey;
    amlPolicyAuthority: PublicKey;
    treasuryPubkey: PublicKey;
    currentTradeId: BN;
    currentOfferId: BN;
    bondSize: BN;
    arbitratorCommission: BN;
    treasuryShare: BN;
    paymentDuration: BN;
    cancelPenaltyRate: BN;
};
export type MarketData = {
    escrowConfig: PublicKey;
    authority: PublicKey;
    marketTokenVaultAccount: PublicKey;
    marketNativeVaultAccount: PublicKey;
    tokenMint: PublicKey;
    totalDepositAmount: BN;
    totalPendingAmount: BN;
    totalAvailableAmount: BN;
    currentTradeId: BN;
    currentOfferId: BN;
    bondSize: BN;
    renecRate: BN;
};
export type KycCertData = {
    level: number;
    totalTradedAmount: BN;
    bump: number;
    dayVolumesHistory: VolumeHistory30Days;
    hourVolumesHistory: VolumeHistory24Hours;
};
export type TokenInfoData = {
    bump: number;
    tokenDecimal: number;
    renecRate: BN;
    minimumOfferAmount: BN;
    quota30Days: BN[];
    quota24Hours: BN[];
};
export type VolumeHistory30Days = {
    head: number;
    volumes: BN[];
    lastApplicableTime: BN;
};
export type VolumeHistory24Hours = {
    head: number;
    volumes: BN[];
    lastApplicableTime: BN;
};
export declare const TradeState: {
    Awaiting: {
        awaiting: {};
    };
    Deposited: {
        deposited: {};
    };
    Disputed: {
        disputed: {};
    };
    Released: {
        released: {};
    };
    Canceled: {
        canceled: {};
    };
};
export declare const OfferState: {
    Awaiting: {
        awaiting: {};
    };
    Canceled: {
        canceled: {};
    };
    OutOfFund: {
        outOfFund: {};
    };
};
export declare const TradeSide: {
    Buy: {
        buy: {};
    };
    Sell: {
        sell: {};
    };
};
export declare const BondType: {
    Native: {
        native: {};
    };
    Spl: {
        spl: {};
    };
};
export declare const DisputeAction: {
    Release: {
        release: {};
    };
    Cancel: {
        cancel: {};
    };
};
export declare const CompensationAction: {
    NoCompensate: {
        noCompensate: {};
    };
    CompensateSeller: {
        compensateSeller: {};
    };
    CompensateBuyer: {
        compensateBuyer: {};
    };
};
export type TradeData = {
    offerId: BN;
    tradeId: BN;
    tradeIdSeed: number[];
    state: object;
    side: object;
    bondType: object;
    escrowConfig: PublicKey;
    configRentVault: PublicKey;
    sellerAuthority: PublicKey;
    sellerTokenAccount: PublicKey;
    buyerAuthority: PublicKey;
    buyerTokenAccount: PublicKey;
    tokenMint: PublicKey;
    tokenVault: PublicKey;
    nativeVault: PublicKey;
    bondAmount: BN;
    tokenAmount: BN;
    fiatAmount: BN;
    createdAt: BN;
    finishedAt: BN;
    bump: number[];
    bankName: string | null;
    accountNumber: string | null;
    accountName: string | null;
    nonce: string | null;
};
export type TradeDataInfo = TradeData & {
    pubkey: PublicKey;
};
export type OfferData = {
    offerId: BN;
    offerIdSeed: number[];
    side: object;
    state: object;
    bondType: object;
    escrowConfig: PublicKey;
    configRentVault: PublicKey;
    makerAuthority: PublicKey;
    makerTokenAccount: PublicKey;
    tokenVaultAccount: PublicKey;
    nativeVaultAccount: PublicKey;
    tokenMint: PublicKey;
    bondAmount: BN;
    fiatAmount: BN;
    totalAmount: BN;
    pendingAmount: BN;
    availableAmount: BN;
    filledAmount: BN;
    minTradeSize: BN;
    createdAt: BN;
    finishedAt: BN;
    bump: number[];
    nativeVaultBump: number[];
    bankName: string | null;
    accountNumber: string | null;
    accountName: string | null;
    nonce: string | null;
};
export type OfferDataInfo = OfferData & {
    pubkey: PublicKey;
};
export type ArbitratorCert = {
    bump: number;
};
export type EvidenceAccountData = {
    bump: number;
    sellerData: string;
    arbitratorData: string;
    nonce: string;
    trade: PublicKey;
};
export type OfferQuotes = {
    tokenMint: PublicKey;
    numOffers: number;
    remainingAccounts: AccountMeta[];
    tradeIds: BN[];
    bumps: number[];
    tradeAmounts?: BN[];
};
